@@ -2,7 +2,7 @@ from typing import List, Optional
 
 from camel_model.camel_model import CamelModel
 
-from domain.distribution.data_block import DataBlock
+from xlsx_lib.domain.distribution.data_block import DataBlock
 
 
 class DistributionData(CamelModel):
