@@ -1,13 +1,8 @@
-from io import BytesIO
-
 from camel_model.camel_model import CamelModel
 
 
 class DistributionImage(CamelModel):
-    name: str
-    format: str
-    file: BytesIO
+    file_name: str
     width: int
     height: int
-    order_index: int
 
