@@ -7,7 +7,7 @@ from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
 from openpyxl.drawing.image import Image
 
-from domain.shared.text_line import TextLine
+from xlsx_lib.domain.shared.text_line import TextLine
 from xlsx_lib.domain.distribution.data_block import DataBlock
 from xlsx_lib.domain.distribution.distribution_image import DistributionImage
 from xlsx_lib.domain.distribution.distribution_cell_value_types import DistributionCellValueType
